Creates a value function for river invertebrates integrating macroinvertebrate indices for organic matter pollution and toxicity.
val.invertebrates.create(language = "English",
dictionaries = NA,
col = "black",
modify = TRUE)The function returns the value function as a class utility.
Language to be used to denote nodes, attributes and attribute levels. Must be a column name of the table provided by the second argument.
Matrix of dictionaries with the languages provided by the column names and the original words provided as the row names.
If dictionary is NA, the default dictionary ecoval.dictionaries.default is loaded.
Color of bounding boxes in objectives hierarchy.
Use the biological indicators Makroindex and IBGN in addition to IBCH. Default is TRUE.
Langhans, S.D., Lienert, J., Schuwirth, N. and Reichert, P.
How to make river assessments comparable: A demonstration for hydromorphology,
Ecological Indicators 32, 264-275, 2013.
tools:::Rd_expr_doi("10.1016/j.ecolind.2013.03.027")
Langhans, S.D., Reichert, P. and Schuwirth, N.
The method matters: indicator aggregation in ecological river assessment.
Ecological Indicators 45, 494-507, 2014.
tools:::Rd_expr_doi("10.1016/j.ecolind.2014.05.014")
Reichert, P., Schuwirth, N. and Langhans, S.
Constructing, evaluating and visualizing value and utility functions for decision support,
Environmental Modelling & Software 46, 283-291, 2013.
tools:::Rd_expr_doi("10.1016/j.envsoft.2013.01.017")
Reichert, P., Langhans, S., Lienert, J. and Schuwirth, N.
The conceptual foundation of environmental decision support.
Journal of Environmental Management. 154, 316-332, 2015.
tools:::Rd_expr_doi("10.1016/j.jenvman.2015.01.053")
Reichert, P., Borsuk, M., Hostmann, M., Schweizer, S., Sporri, C., Tockner, K. and Truffer, B.
Concepts of decision support for river rehabilitation,
Environmental Modelling and Software 22, 188-201, 2007.
tools:::Rd_expr_doi("10.1016/j.envsoft.2005.07.017")
https://modul-stufen-konzept.ch
Stucki P.
Methoden zur Untersuchung und Beurteilung der Fliessgewaesser - Makrozoobenthos Stufe F.
Bundesamt fuer Umwelt, Bern. Umwelt-Vollzug Nr. 1026: 61 S. 2010.
http://www.bafu.admin.ch/uv-1026-d
Indice Biologique Global Normalise IBGN, NF-T90-350. Guide Technique.
Agences de l'Eau, 2000.
https://hal.archives-ouvertes.fr/hal-00490432/document
Beketov M.A., Foit K., Schafer R.B., Schriever C.A., Sacchi A., Capri E., Biggs J., Wells C. & Liess M.
SPEAR indicates pesticide effects in streams - Comparative use of species- and family-level biomonitoring data.
Environmental Pollution, 157, 1841-1848, 2009.
tools:::Rd_expr_doi("10.1016/j.envpol.2009.01.021")
utility.
invertebrates <- val.invertebrates.create()
plot(invertebrates)
invertebrates.german <- val.invertebrates.create("Deutsch")
plot(invertebrates.german)
Run the code above in your browser using DataLab